@@ -20,9 +20,11 @@
 
 use 5.014_001;
 
-package Term::CLI::Argument::Number  0.03002 {
+package Term::CLI::Argument::Number  0.04001 {
 
 use Modern::Perl;
+use Term::CLI::L10N;
+
 use Moo;
 use namespace::clean;
 
@@ -40,29 +42,29 @@ sub validate {
     my ($self, $value) = @_;
 
     if (!defined $value || length($value) == 0) {
-        return $self->set_error('not a valid number');
+        return $self->set_error(loc('not a valid number'));
     }
 
-    my ($num, $unparsed) = $self->coerce_value($value);
+    my $num = $self->coerce_value($value);
 
-    if ($unparsed) {
-        return $self->set_error('not a valid number');
+    if (!defined $num) {
+        return $self->set_error(loc('not a valid number'));
     }
 
     if ($self->inclusive) {
         if ($self->has_min && $num < $self->min) {
-            return $self->set_error('too small');
+            return $self->set_error(loc('too small'));
         }
         elsif ($self->has_max && $num > $self->max) {
-            return $self->set_error('too large');
+            return $self->set_error(loc('too large'));
         }
     }
     else {
         if ($self->has_min && $num <= $self->min) {
-            return $self->set_error('too small');
+            return $self->set_error(loc('too small'));
         }
         elsif ($self->has_max && $num >= $self->max) {
-            return $self->set_error('too large');
+            return $self->set_error(loc('too large'));
         }
     }
     return $num;
@@ -82,7 +84,7 @@ Term::CLI::Argument::Number - base class for numerical arguments in Term::CLI
 
 =head1 VERSION
 
-version 0.03002
+version 0.04001
 
 =head1 SYNOPSIS
 
@@ -194,16 +196,14 @@ a suitable number and then checks any boundaries.
 
 This method I<must> be overridden by sub-classes.
 
-Its function interface should be identical to that of L<POSIX>'s C<strtod>
-and C<strtol> functions. It will be called with a single argument (the
-I<VALUE>) and is supposed to return a list of two values: the converted
-number and the number of unparsed characters in I<VALUE>.
+It will be called with a single argument (the I<VALUE>) and is
+supposed to return the converted number. If the number is not
+valid, it should return C<undef>.
 
 =back
 
 =head1 SEE ALSO
 
-L<POSIX>(3p),
 L<Term::CLI::Argument>(3p),
 L<Term::CLI>(3p).
 
