@@ -20,17 +20,22 @@
 
 use 5.014_001;
 
-package Term::CLI::Argument::Number::Float  0.03002 {
+package Term::CLI::Argument::Number::Float  0.04001 {
 
 use Modern::Perl;
 use POSIX qw( );
+use Scalar::Util qw( looks_like_number );
+
 use Moo;
 use namespace::clean;
 
 extends 'Term::CLI::Argument::Number';
 
 sub coerce_value {
-    return POSIX::strtod($_[1]);
+    if (looks_like_number($_[1])) {
+        return $_[1] + 0.0;
+    }
+    return undef;
 }
 
 }
@@ -47,7 +52,7 @@ Term::CLI::Argument::Number::Float - class for floating point arguments in Term:
 
 =head1 VERSION
 
-version 0.03002
+version 0.04001
 
 =head1 SYNOPSIS
 
@@ -92,13 +97,14 @@ Additionally:
 
 =item B<coerce_value> ( I<VALUE> )
 
-Overloaded to call L<POSIX::strtod|POSIX/strtod>.
+Overloaded to check for a valid numerical
+value (using L<Scalar::Util's looks_like_number|Scalar::Util/looks_like_number>).
 
 =back
 
 =head1 SEE ALSO
 
-L<POSIX>(3p),
+L<Scalar::Util>(3p),
 L<Term::CLI::Argument::Number::Int>(3p),
 L<Term::CLI::Argument::Number>(3p),
 L<Term::CLI::Argument>(3p),
