@@ -20,7 +20,7 @@
 
 use 5.014_001;
 
-package Term::CLI::Command::Help  0.03002 {
+package Term::CLI::Command::Help  0.04001 {
 
 use Modern::Perl;
 use Pod::Text::Termcap;
@@ -28,6 +28,7 @@ use List::Util qw( first );
 use File::Which;
 use Types::Standard qw( ArrayRef Str );
 use Getopt::Long qw( GetOptionsFromArray );
+use Term::CLI::L10N;
 
 my @PAGERS = (
     [qw(
@@ -38,7 +39,7 @@ my @PAGERS = (
     ['more'], ['pg'],
 );
 
-my @PAGER = 'cat';
+my @PAGER = '/bin/cat';
 if (my $pager = first { defined which($_->[0]) } @PAGERS) {
     @PAGER = @$pager;
 }
@@ -73,14 +74,14 @@ has '+options' => (
 
 has '+description' => (
     default => sub {
-        qq{Show help for any given command sequence.\n}
-        .qq{The C<--pod> option (or C<-p>) will cause raw POD\n}
-        .qq{to be shown.}
+        loc(qq{Show help for any given command sequence.\n}
+           .qq{The C<--pod> option (or C<-p>) will cause raw POD\n}
+           .qq{to be shown.});
     }
 );
 
 has '+summary' => (
-    default => sub { 'show help' },
+    default => sub { loc('show help') },
 );
 
 #has '+usage' => (
@@ -120,6 +121,8 @@ sub _make_command_summary {
 
     my $text = '';
     my $over_width = int(($self->term->term_width - 4) / 3);
+    $over_width = 40 if $over_width > 40;
+
     my $full_pod = $pod_prefix."=over $over_width\n\n";
 
     for my $cmd_ref (@$commands) {
@@ -154,7 +157,7 @@ sub _get_help {
         my ($pod, $text)
             = $self->_make_command_summary(
                 cmd_path   => [],
-                pod_prefix => "=head2 Commands:\n\n",
+                pod_prefix => "=head2 ".loc("Commands").":\n\n",
                 commands   => [$self->root_node->commands]
             );
         return (%args, pod => $pod, text => $text);
@@ -181,18 +184,20 @@ sub _get_help {
     }
 
     my $last_cmd = pop @cmd_ref_path;
-    my $usage_prefix = join(' ', map { $_->usage_text(with_options => 'none', with_subcommands => 0) } @cmd_ref_path);
+    my $usage_prefix = join(' ',
+        map { $_->usage_text(with_options => 'none', with_subcommands => 0) }
+        @cmd_ref_path
+    );
     $usage_prefix .= ' ' if length $usage_prefix;
-    my $pod .= "=head2 Usage:\n\n";
+    my $pod .= "=head2 ".loc("Usage").":\n\n";
     for my $usage ($last_cmd->usage_text(with_options => 'both')) {
-        #$pod .= "=item $usage_prefix$usage\n\n";
         $pod .= "$usage_prefix$usage\n\n";
     }
     $pod =~ s/\n*$//s;
     $pod .= "\n\n";
 
     if (my $description = $cur_cmd_ref->description) {
-        $pod .= "=head2 Description:\n\n";
+        $pod .= "=head2 ".loc("Description").":\n\n";
         $pod .= $cur_cmd_ref->description;
     }
     elsif (my $summary = $cur_cmd_ref->summary) {
@@ -209,7 +214,7 @@ sub _get_help {
         my ($cmd_pod, $cmd_text) =
             $self->_make_command_summary(
                 cmd_path => \@cmd_path,
-                pod_prefix => "=head2 Sub-Commands:\n\n",
+                pod_prefix => "=head2 ".loc("Sub-Commands").":\n\n",
                 commands => [$cur_cmd_ref->commands],
             );
         $pod .= $cmd_pod;
@@ -296,7 +301,7 @@ sub _execute_help {
     { no warnings 'exec';
         if (!open $pager_fh, "|-", @{$pager_cmd}) {
             $args{status} = -1;
-            $args{error} = "cannot run '$$pager_cmd[0]': $!";
+            $args{error} = loc("cannot run '[_1]': [_2]", $$pager_cmd[0], $!);
             return %args;
         }
     }
@@ -328,7 +333,7 @@ Term::CLI::Command::Help - A generic 'help' command for Term::CLI
 
 =head1 VERSION
 
-version 0.03002
+version 0.04001
 
 =head1 SYNOPSIS
 
